@@ -33,9 +33,8 @@ KMeans=function(X,K,V,r,max.iter,truere,method=0){
 #'  X1<-matrix(view1,n1+n2+n3,1)
 #'  X2<-matrix(view2,n1+n2+n3,1)
 #'  KMeans(X=X1,K=K,V=V,r=r,max.iter=max.iter,truere=truere,method=0)
-
-    if (V<=1){
-
+  if (V<=1){
+## KMeans for single-view
      rows <- nrow(X) 
      cols <- ncol(X)
      within <- matrix(0,nrow=K,ncol=1) 
@@ -80,33 +79,35 @@ KMeans=function(X,K,V,r,max.iter,truere,method=0){
     }
     iter=(iter+1) 
 } }
-
+## KMeans for multi-views
   if (V>1){
   N1=nrow(X)
   J1=ncol(X)
   iter=0
   changed=2
-  Alpha<-1/V 
+  Alpha<-1/V  
   D<-diag(N1)    
+
 U1<-matrix(0,nrow=N1,ncol=K)
 for(i in 1:N1 )  {
  mr=sample(1:K,1,replace=FALSE)
 U1[i,mr]=1
-} 
+}  
 M1 <- matrix(0,nrow=K,ncol=J1)
 M11 <- matrix(0,nrow=K,ncol=J1)
+
  SJS <- as.vector(sample(1:N1,size=K))
 
 for (k in 1:K) { 
     M1[k,] <- X[SJS[k],] 
     M1 <- matrix(M1,K,J1)
-      }    
+      }     
 change=1
 u<-matrix(0,1,K)
 g<-matrix(0,1,K)
 value<-matrix(0,1,K)
 P1<-matrix(0,1,N1)
-
+system.time(
 while(change>0.1){
 M11=M1
 if(iter>=max.iter)
@@ -133,12 +134,12 @@ for (j in 1:N1){
 D[j,j]<-(1/(2*value5))
 }
 value6<-diag(value5)
-value7<-sum(value6) 
+value7<-sum(value6)
 Alpha1<-(r*value7)^(1/(1-r))
 change=norm((M11-M1),type="1")
 iter=(iter+1)
 }
- }
+) }
     if(V<=1){
 ccc<-c(indexMatrix[,1])
 center=M
@@ -154,7 +155,7 @@ H_indexre<-(-sum(kf1*log(kf1)))
 tfrequency<-as.data.frame(table(truere)) 
 kf2<-tfrequency$Freq/length(truere) 
 H_truere<-(-sum(kf2*log(kf2)))
-cfrequency<-as.data.frame(table(paste(ccc,truere)))
+cfrequency<-as.data.frame(table(paste(ccc,truere))) 
 kf3<-cfrequency$Freq/length(paste(ccc,truere)) 
 H_paste<-(-sum(kf3*log(kf3)))
 MI<-H_indexre+H_truere- H_paste
